# Problem Bank Helpers 

[![Python](https://img.shields.io/badge/python-3.9-blue)]()
[![codecov](https://codecov.io/gh/open-resources/problem_bank_helpers/branch/main/graph/badge.svg)](https://codecov.io/gh/open-resources/problem_bank_helpers)
[![Documentation Status](https://readthedocs.org/projects/problem_bank_helpers/badge/?version=latest)](https://problem_bank_helpers.readthedocs.io/en/latest/?badge=latest)


## Installation

```bash
$ pip install -i https://test.pypi.org/simple/ problem_bank_helpers
```

## Features

- TODO

## Dependencies

- TODO

## Usage

- TODO

## Documentation

The official documentation is hosted on Read the Docs: https://problem_bank_helpers.readthedocs.io/en/latest/

## Contributors

We welcome and recognize all contributions. You can see a list of current contributors in the [contributors tab](https://github.com/open-resources/problem_bank_helpers/graphs/contributors).

### Credits

This package was created with Cookiecutter and the UBC-MDS/cookiecutter-ubc-mds project template, modified from the [pyOpenSci/cookiecutter-pyopensci](https://github.com/pyOpenSci/cookiecutter-pyopensci) project template and the [audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage).
